<?php
namespace PAE\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error; 
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\XLS\Exception as XlsException;
use PAE\Strategies;
use PAE\Strategies\Context;
use PAE\Controllers\Import\XlsImportFile;

class Ger00000CadastramentosAutomaticoController
{
    public function __construct(Strategies\MarcaStrategy $marcaStrategy)
    {
		$this->marcaStrategy = $marcaStrategy;
	}
	
	public function setContext($tableName)
	{
	    switch ($tableName) {
            case 'MARCA':
                $context = new Context($this->marcaStrategy);
                break;
            
            default:
                throw new Exception("Não existe estratégia para a tabela informada!", 400);
                break;
        }
        
	    return $context;
	}
	
    public function importXls(DTO\Request $request, DTO\Response $response)
    {
        try {
            $xlsImport = new XlsImportFile;
            
            $row = $request->getRow();
            $xlsImport->setColumnNames($row['CAMPOS']);
            
            $rows = $xlsImport->importData($row);
            
            $context = self::setContext($row['TABLE_NAME']);
            
            $context->validate($rows);
            
            $context->formatToView($rows);
            
            $response->addDataSet(new DataSet('import', $rows));
            
        } catch(XlsException $e) {
            $errors = $e->getErrors();
            $response->addDataSet(new DataSet('errors', $errors));
            $response->setError(new Error($e->getMessage(), 500));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function saveImport(DTO\Request $request, DTO\Response $response)
    {
        try {
            $data = $request->getDataSet()->getRows()[0];
            
            $rows = $data['ROWS'];
            $tableName = $data['TABLE_NAME'];
            
            if (empty($rows))
                throw new Exception("Não há dados!", 400);
            
            $context = self::setContext($tableName);
            
            $context->formatToSave($rows);
            
            $context->save($rows);
            
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    
    //A função a baixo deve ficar na validação de cada strategy
    public function verificaPrimaryKey(DTO\Request $request, DTO\Response $response)
    {
        try {
            $dataSet = $request->getDataSet()->getRows();
            
            $errors = $this->service->verificaDado($dataSet);
            
            $response->addDataSet(new DataSet('errors', $errors));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
}
